@@ -293,7 +293,7 @@ use strict;
 use warnings;
 use bytes;
 
-our $VERSION = '1.40';
+our $VERSION = '1.43';
 
 require XSLoader;
 XSLoader::load('Cache::FastMmap', $VERSION);
@@ -328,7 +328,7 @@ parent that forks off children to ensure that file is empty at the start
 B<Note:> This is quite important to do in the parent to ensure a
 consistent file structure. The shared file is not perfectly transaction
 safe, and so if a child is killed at the wrong instant, it might leave
-the the cache file in an inconsistent state.
+the cache file in an inconsistent state.
 
 =item * B<raw_values>
 
@@ -782,7 +782,7 @@ sub set {
 Atomically retrieve and set the value of a Key.
 
 The page is locked while retrieving the $Key and is unlocked only after
-the value is set, thus guaranteeing the value does not change betwen
+the value is set, thus guaranteeing the value does not change between
 the get and set operations.
 
 $Sub is a reference to a subroutine that is called to calculate the
@@ -790,6 +790,11 @@ new value to store. $Sub gets $Key and the current value
 as parameters, and
 should return the new value to set in the cache for the given $Key.
 
+If the subroutine returns an empty list, no value is stored back
+in the cache. This avoids updating the expiry time on an entry
+if you want to do a "get if in cache, store if not present" type
+callback.
+
 For example, to atomically increment a value in the cache, you
 can just use:
 
@@ -824,9 +829,15 @@ sub get_and_set {
   my ($Self, $Cache) = ($_[0], $_[0]->{Cache});
 
   my ($Value, $Unlock) = $Self->get($_[1], { skip_unlock => 1 });
+
   # If this throws an error, $Unlock ref will still unlock page
-  $Value = $_[2]->($_[1], $Value);
-  my $DidStore = $Self->set($_[1], $Value, { skip_lock => \$Unlock });
+  my @NewValue = $_[2]->($_[1], $Value);
+
+  my $DidStore = 0;
+  if (@NewValue) {
+    ($Value) = @NewValue;
+    my $DidStore = $Self->set($_[1], $Value, { skip_lock => \$Unlock });
+  }
 
   return wantarray ? ($Value, $DidStore) : $Value;
 }
@@ -1377,10 +1388,10 @@ Rob Mueller L<mailto:cpan@robm.fastmail.fm>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2003-2011 by Opera Software Australia Pty Ltd
+Copyright (C) 2003-2015 by FastMail Pty Ltd
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. 
+it under the same terms as Perl itself.
 
 =cut
 
